@@ -6,10 +6,9 @@
 #'
 #' @import ggplot2
 #' @importFrom ggpubr ggarrange
-#' @importFrom tidyr complete_
+#' @importFrom dplyr right_join
 #' @param p The result of \code{plot.light_effects}.
 #' @param x An object of class \code{light_effects}.
-#' @param zero_counts Logical flag if 0 count levels should be shown.
 #' @param text_size Size of count labels.
 #' @param facet_scales Scales argument passed to \code{facet_wrap}.
 #' @param show_labels Should counts be added as text?
@@ -25,26 +24,30 @@
 #' mod_part <- flashlight(model = fit_part, label = "part", data = iris, y = "Sepal.Length")
 #' mods <- multiflashlight(list(mod_full, mod_part))
 #'
-#' x <- light_effects(mod_full, v = "Petal.Width")
+#' x <- light_effects(mod_full, v = "Petal.Width", stats = "quartiles")
 #' plot_counts(plot(x), x, width = 0.3, alpha = 0.2)
+#' plot_counts(plot(x, zero_counts = FALSE), x, width = 0.3, alpha = 0.2)
 #' plot_counts(plot(x), x, width = 0.3, alpha = 0.2, show_labels = FALSE)
 #' plot_counts(plot(x, use = "response"), x, fill = "lightblue")
 #' plot_counts(plot(x, use = "pd", show.legend = FALSE), x, fill = "lightblue")
 #' @seealso \code{\link{plot.light_effects}}.
 #' @export
-plot_counts <- function(p, x, zero_counts = TRUE, text_size = 3, facet_scales = "free_x",
+plot_counts <- function(p, x, text_size = 3, facet_scales = "free_x",
                         show_labels = TRUE, big.mark = "'", scientific = FALSE, ...) {
   # Checks
   stopifnot(is.ggplot(p), is.light_effects(x),
             !("lab_" %in% colnames(x$response)))
 
-  nby <- length(x$by)
   multi <- is.light_effects_multi(x)
 
-  if (zero_counts && (nby + multi) >= 1L) {
-    x$response <- complete_(x$response, cols = c(x$by, x$v, x$label_name),
-                            fill = setNames(list(0), x$counts_name))
+  # Deal with zero counts
+  key <- c(x$by, x$v, x$label_name)
+  x$response <- right_join(x$response, unique(p$data[, key, drop = FALSE]), by = key)
+  if (any((bad <- is.na(x$response[[x$counts_name]])))) {
+    x$response[[x$counts_name]][bad] <- 0
   }
+
+  # Prepare for plotting
   if (show_labels) {
     x$response[["lab_"]] <- format(x$response[[x$counts_name]],
                                    big.mark = big.mark, scientific = scientific)
@@ -57,7 +60,7 @@ plot_counts <- function(p, x, zero_counts = TRUE, text_size = 3, facet_scales =
     ct <- ct + geom_text(aes_string(y = 0, label = "lab_"),
                          angle = 90, hjust = -0.1, size = text_size)
   }
-  if (multi || nby) {
+  if (multi || length(x$by)) {
     ct <- ct + facet_wrap(reformulate(if (multi) x$label_name else x$by[1]),
                           scales = facet_scales, nrow = 1L)
   }
